@@ -14,6 +14,10 @@ def register():
         ShipmentIn,
         ShipmentOut,
         ShipmentOutReturn,
+        Period,
+        PeriodCacheLot,
+        Inventory,
+        InventoryLine,
         Template,
         Product,
         TemplateLotType,
